
Tao Interface
=============

This module defines the `tao_interface` class, a general purpose interface
between *Tao* and python that supports both the ctypes and pexpect backend
implementations.  Also defined here are a couple of helper functions for the
`tao_interface` class.

.. autoclass:: pytao.tao_interface.tao_interface
   :members:
   :noindex:


Tao Command Interface
=====================

This module wraps all calls to *Tao* `python` commands in a simple python
functions.

The functions are autogenerated from parsing a JSON file that containes the
docstrings from the `tao_python_cmd.f90`. At the root of this codebase there
is a script called `generate_interface_commands.py` which outputs this module
and also automated tests based on the examples defined on the docstrings.

.. automodule:: pytao.interface_commands
   :members:
   :noindex:
